@@ -24,19 +24,25 @@ our $VERSION = do { my @r = ( q$Revision: 2.17 $ =~ /\d+/g ); sprintf "%d." . "%
 
 use constant DEBUG_FRAME => 0;
 
+# use Log4perl if we have it, otherwise stub:
+# See Log::Log4perl::FAQ
 BEGIN {
 	eval { require Log::Log4perl; };
 	if($@) {
-		no strict qw(refs);
-		*{"Tk::Wizard::Installer::Win32::$_"} = sub { } for qw(TRACE DEBUG INFO WARN ERROR FATAL);
-		if (__PACKAGE__ ne 'Tk::Wizard::Installer::Win32'){
-			*{__PACKAGE__."::$_"} = sub { } for qw(TRACE DEBUG INFO WARN ERROR FATAL);
-		}
+		no strict qw"refs";
+		*{__PACKAGE__."::$_"} = sub { } for qw(TRACE DEBUG INFO WARN ERROR FATAL);
 	} else {
 		no warnings;
+		no strict qw"refs";
 		require Log::Log4perl::Level;
 		Log::Log4perl::Level->import(__PACKAGE__);
 		Log::Log4perl->import(":easy");
+		# It took four CPAN uploads and tests to workout why
+		# one user was getting syntax errors for TRACE: must
+		# be the Mithrasmas spirit (hic):
+		if ($Log::Log4perl::VERSION < 1.11){
+			*{__PACKAGE__."::TRACE"} = *DEBUG;
+		}
 	}
 
     use Win32::Shortcut;
